@@ -29,7 +29,6 @@
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 #include <gst/gst.h>
-#include <libgnomevfs/gnome-vfs.h>
 
 #include "cheese-fileutil.h"
 #include "cheese-window.h"
@@ -198,9 +197,6 @@ main (int argc, char **argv)
     return -1;
   }
 
-  /* Needed for gnome_thumbnail functions */
-  gnome_vfs_init ();
-
   g_set_print_handler ((GPrintFunc) cheese_print_handler);
 
   gtk_window_set_default_icon_name ("cheese");
